| Title: | Multiplier Data Envelopment Analysis and Cross Efficiency |
|---|---|
| Description: | Functions are provided for calculating efficiency using multiplier DEA (Data Envelopment Analysis): Measuring the efficiency of decision making units (Charnes et al., 1978 <doi:10.1016/0377-2217(78)90138-8>) and cross efficiency using single and two-phase approach. In addition, it includes some datasets for calculating efficiency and cross efficiency. |
| Authors: | Aurobindh Kalathil Puthanpura <[email protected]> |
| Maintainer: | Aurobindh Kalathil Puthanpura <[email protected]> |
| License: | LGPL-2 |
| Version: | 0.1.19 |
| Built: | 2026-05-24 06:02:27 UTC |
| Source: | https://github.com/cran/MultiplierDEA |
Bank Branch data for Operating Efficiency.
Bank_Branch_Operating_EfficiencyBank_Branch_Operating_Efficiency
A data frame containing data for 17 Bank Branches.
Branch_Codea character vector
PHa numeric vector
OEa numeric vector
SQMa numeric vector
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Giokas DI (1991) Bank branck operating efficiency: A comparative application of DEA and the Loglinear model, OMEGA International Journal of Management Science, 19 (6) 549-557.
Giokas DI (1991) Bank branck operating efficiency: A comparative application of DEA and the Loglinear model, OMEGA International Journal of Management Science, 19 (6) 549-557.
data(Bank_Branch_Operating_Efficiency) attach(Bank_Branch_Operating_Efficiency) x <- data.frame(PH, OE, SQM) rownames(x) <- Branch_Code colnames(x) <- colnames(Bank_Branch_Operating_Efficiency)[2:4] y <- data.frame(A, B, C, D) rownames(y) <- Branch_Code colnames(y) <- colnames(Bank_Branch_Operating_Efficiency)[5:8] detach(Bank_Branch_Operating_Efficiency) # For CRS result_CRS <- DeaMultiplierModel(x,y,"crs", "input") # For VRS result_VRS <- DeaMultiplierModel(x,y,"crs", "input")data(Bank_Branch_Operating_Efficiency) attach(Bank_Branch_Operating_Efficiency) x <- data.frame(PH, OE, SQM) rownames(x) <- Branch_Code colnames(x) <- colnames(Bank_Branch_Operating_Efficiency)[2:4] y <- data.frame(A, B, C, D) rownames(y) <- Branch_Code colnames(y) <- colnames(Bank_Branch_Operating_Efficiency)[5:8] detach(Bank_Branch_Operating_Efficiency) # For CRS result_CRS <- DeaMultiplierModel(x,y,"crs", "input") # For VRS result_VRS <- DeaMultiplierModel(x,y,"crs", "input")
The Relationship between benchmark tests and Microcomputer price data.
BenchMark_Tests_And_MicrocomputerBenchMark_Tests_And_Microcomputer
A data frame containing data for 22 Microcomputers.
Systema character vector
Pricea numeric vector
MemorySizea numeric vector
DiskCapacitya numeric vector
CPUa numeric vector
IOa numeric vector
RL1a numeric vector
RL2a numeric vector
RL3a numeric vector
Sircar S. and Dave D (1986) Tbe relationship between benchmark tests and microcomputer price. Communications of the ACM, 29, 212-217.
Sircar S. and Dave D (1986) Tbe relationship between benchmark tests and microcomputer price. Communications of the ACM, 29, 212-217.
data(BenchMark_Tests_And_Microcomputer) attach(BenchMark_Tests_And_Microcomputer) x <- BenchMark_Tests_And_Microcomputer detach(BenchMark_Tests_And_Microcomputer)data(BenchMark_Tests_And_Microcomputer) attach(BenchMark_Tests_And_Microcomputer) x <- BenchMark_Tests_And_Microcomputer detach(BenchMark_Tests_And_Microcomputer)
Cross Efficiency uses DEA to do peer evaluation of DMUs. Single-phase cross efficiency approach.
CrossEfficiency(x = x, y = y, rts = "crs", orientation = "input", weightRestriction)CrossEfficiency(x = x, y = y, rts = "crs", orientation = "input", weightRestriction)
x |
Inputs or resources used by each decision making unit. |
y |
Outputs or resources used by each decision making unit. |
rts |
Returns to scale for the application, or industry studied. Note the default rts is crs. vrs Variable returns to scale. crs Constant returns to scale. |
orientation |
Orientation of the DEA model - primary emphasis on input-reduction input or output-augmentation output. Note that unlike the DEA functions, the default is input orientation. |
weightRestriction |
Weight restriction for the model. Optional parameter. |
The function returns a number of values per DMU.
$ceva_matrix |
Returns the cross efficiency matrix. Row is the Rating DMU and Column is the Rated DMU. |
$ce_ave |
Returns the cross efficiency score for the DMU. |
$ceva_max |
Returns the maximum cross efficiency score for the DMU. |
$ceva_min |
Returns the minimum cross efficiency score for the DMU. |
$vx |
Input weights from the model. |
$uy |
Output weights from the model. |
$Model_Status |
Returns the status of the LP model. |
ceva_matrix - cross-evaluation matrix. ceva_max - cross-evaluation maximum. ceva_min - cross-evaluation minimum. ce_ave - cross-efficiency scores.
#Example from Kenneth R. Baker: Optimization Modeling with Spreadsheets, Third Edition,p. 176, #John Wiley and Sons, Inc. dmu <- c("A", "B", "C", "D", "E", "F") x <- data.frame(c(150,400,320,520,350,320),c(0.2,0.7,1.2,2.0,1.2,0.7)) rownames(x) <- dmu colnames(x)[1] <- c("StartHours") colnames(x)[2] <- c("Supplies") y <- data.frame(c(14,14,42,28,19,14),c(3.5,21,10.5,42,25,15)) rownames(y) <- dmu colnames(y)[1] <- c("Reimbursed") colnames(y)[2] <- c("Private") # Calculate the efficiency score result <- CrossEfficiency(x,y,"crs", "input") # Examine the cross efficiency score for DMUs print(result$ce_ave)#Example from Kenneth R. Baker: Optimization Modeling with Spreadsheets, Third Edition,p. 176, #John Wiley and Sons, Inc. dmu <- c("A", "B", "C", "D", "E", "F") x <- data.frame(c(150,400,320,520,350,320),c(0.2,0.7,1.2,2.0,1.2,0.7)) rownames(x) <- dmu colnames(x)[1] <- c("StartHours") colnames(x)[2] <- c("Supplies") y <- data.frame(c(14,14,42,28,19,14),c(3.5,21,10.5,42,25,15)) rownames(y) <- dmu colnames(y)[1] <- c("Reimbursed") colnames(y)[2] <- c("Private") # Calculate the efficiency score result <- CrossEfficiency(x,y,"crs", "input") # Examine the cross efficiency score for DMUs print(result$ce_ave)
City data for Operating Efficiency.
data("Data_City")data("Data_City")
A data frame containing data for 15 city observations
DMUa numeric vector
Citya character vector
Housepricea numeric vector
Rentala numeric vector
Violenta numeric vector
Incomea numeric vector
B.Degreea numeric vector
Doctora numeric vector
W.D. Cook, L. Liang, Y. Zha and J.Zhu (2009) A Modified Super-Efficiency DEA Model for Infeasibility, The Journal of the Operational Research Society Vol. 60, No. 2 (Feb., 2009), pp. 276-281.
W.D. Cook, L. Liang, Y. Zha and J.Zhu (2009) A Modified Super-Efficiency DEA Model for Infeasibility, The Journal of the Operational Research Society Vol. 60, No. 2 (Feb., 2009), pp. 276-281.
data(Data_City) attach(Data_City)data(Data_City) attach(Data_City)
DEA multiplier model calculates the efficieny and reference sets for each DMUs.
DeaMultiplierModel(x = x, y = y, rts = "crs", orientation = "input", weightRestriction)DeaMultiplierModel(x = x, y = y, rts = "crs", orientation = "input", weightRestriction)
x |
Inputs or resources used by each decision making unit. |
y |
Outputs or resources used by each decision making unit. |
rts |
Returns to scale for the application, or industry studied. Note the default rts is crs. vrs Variable returns to scale. crs Constant returns to scale. Available option: crs, vrs |
orientation |
Orientation of the DEA model - primary emphasis on input-reduction or output-augmentation output. Note that unlike the DEA functions, the default is input orientation. Available option: input, output. |
weightRestriction |
Weight restriction for the model. Optional parameter. |
The function returns a number of values per DMU. The standardized efficiency (all inefficiencies are between 0 and 1, for input and output orientation). Efficiency, and lambda values are returned.
$rts |
Returns to scale of the model. |
$Orientation |
Orientation of the model. |
$InputValues |
Input Values (x) passed to the model. |
$OutputValues |
Output Values (y) passed to the model. |
$Efficiency |
Efficiency of each DMU in the model. |
$Lambda |
Lambdas per DMU in the model. |
$HCU_Input |
HCU data for inputs. |
$HCU_Output |
HCU data for outputs. |
$vx |
Input weights from the model. |
$uy |
Output weights from the model. |
$Free_Weights |
Free weights from the model. Applies only to vrs returns-to-scale. |
$Model_Status |
Returns the status of the LP model. |
#Example from Kenneth R. Baker: Optimization Modeling with Spreadsheets, Third Edition,p. 176, #John Wiley and Sons, Inc. dmu <- c("A", "B", "C", "D", "E", "F") x <- data.frame(c(150,400,320,520,350,320),c(0.2,0.7,1.2,2.0,1.2,0.7)) rownames(x) <- dmu colnames(x)[1] <- c("StartHours") colnames(x)[2] <- c("Supplies") y <- data.frame(c(14,14,42,28,19,14),c(3.5,21,10.5,42,25,15)) rownames(y) <- dmu colnames(y)[1] <- c("Reimbursed") colnames(y)[2] <- c("Private") #Creating the weight restriction data frame with Upper bound weightRestriction<-data.frame(lower = c(1), numerator = c("StartHours"), denominator = c("Supplies"), upper = c(2)) #Creating the weight restriction data frame without Upper bound weightRestriction<-data.frame(lower = c(1), numerator = c("StartHours"), denominator = c("Supplies")) #Creating the weight restriction data frame with Upper bound and Na, Inf or NaN weightRestriction<-data.frame(lower = c(1,2), numerator = c("StartHours","Reimbursed"), denominator = c("Supplies","Private"), upper = c(2,Inf)) # Calculate the efficiency score without weight Restriction result <- DeaMultiplierModel(x,y,"crs", "input") # Examine the efficiency score for DMUs print(result$Efficiency) # Calculate the efficiency score with weight Restriction result <- DeaMultiplierModel(x,y,"crs", "input", weightRestriction) # Examine the efficiency score for DMUs print(result$Efficiency)#Example from Kenneth R. Baker: Optimization Modeling with Spreadsheets, Third Edition,p. 176, #John Wiley and Sons, Inc. dmu <- c("A", "B", "C", "D", "E", "F") x <- data.frame(c(150,400,320,520,350,320),c(0.2,0.7,1.2,2.0,1.2,0.7)) rownames(x) <- dmu colnames(x)[1] <- c("StartHours") colnames(x)[2] <- c("Supplies") y <- data.frame(c(14,14,42,28,19,14),c(3.5,21,10.5,42,25,15)) rownames(y) <- dmu colnames(y)[1] <- c("Reimbursed") colnames(y)[2] <- c("Private") #Creating the weight restriction data frame with Upper bound weightRestriction<-data.frame(lower = c(1), numerator = c("StartHours"), denominator = c("Supplies"), upper = c(2)) #Creating the weight restriction data frame without Upper bound weightRestriction<-data.frame(lower = c(1), numerator = c("StartHours"), denominator = c("Supplies")) #Creating the weight restriction data frame with Upper bound and Na, Inf or NaN weightRestriction<-data.frame(lower = c(1,2), numerator = c("StartHours","Reimbursed"), denominator = c("Supplies","Private"), upper = c(2,Inf)) # Calculate the efficiency score without weight Restriction result <- DeaMultiplierModel(x,y,"crs", "input") # Examine the efficiency score for DMUs print(result$Efficiency) # Calculate the efficiency score with weight Restriction result <- DeaMultiplierModel(x,y,"crs", "input", weightRestriction) # Examine the efficiency score for DMUs print(result$Efficiency)
Evaluation the Efficiency of UK University Departments Of Accounting Efficiency.
Departments_Of_AccountingDepartments_Of_Accounting
A data frame containing data for 20 UK University Departments Of Accounting.
Departmentsa numeric vector
Undergraduatesa numeric vector
Researcha numeric vector
Taughta numeric vector
Res.Coa numeric vector
OtherResa numeric vector
OtherIncomea numeric vector
Publicationsa numeric vector
AcademicStaffa numeric vector
Salariesa numeric vector
OtherExpa numeric vector
Tomkins C and Green RH (1988) An experiment in the use of data envelopment analysis for evaluating the efficiency of UK university departments of accounting. Financial Accounting and Management, 4, 147-164.
Tomkins C and Green RH (1988) An experiment in the use of data envelopment analysis for evaluating the efficiency of UK university departments of accounting. Financial Accounting and Management, 4, 147-164.
data(Departments_Of_Accounting) attach(Departments_Of_Accounting) x <- data.frame(AcademicStaff) rownames(x) <- Departments colnames(x) <- colnames(Departments_Of_Accounting)[9] y <- data.frame(Undergraduates, Research, Taught,(Res.Co + OtherRes + OtherIncome)) rownames(y) <- Departments colnames(y)[1] <- colnames(Departments_Of_Accounting)[2] colnames(y)[2] <- colnames(Departments_Of_Accounting)[3] colnames(y)[3] <- colnames(Departments_Of_Accounting)[4] colnames(y)[4] <- c("Total_Income") detach(Departments_Of_Accounting) result <- DeaMultiplierModel(x,y,"crs", "input")data(Departments_Of_Accounting) attach(Departments_Of_Accounting) x <- data.frame(AcademicStaff) rownames(x) <- Departments colnames(x) <- colnames(Departments_Of_Accounting)[9] y <- data.frame(Undergraduates, Research, Taught,(Res.Co + OtherRes + OtherIncome)) rownames(y) <- Departments colnames(y)[1] <- colnames(Departments_Of_Accounting)[2] colnames(y)[2] <- colnames(Departments_Of_Accounting)[3] colnames(y)[3] <- colnames(Departments_Of_Accounting)[4] colnames(y)[4] <- c("Total_Income") detach(Departments_Of_Accounting) result <- DeaMultiplierModel(x,y,"crs", "input")
Provides the solver status codes and description.
#List status codes and description. dict.solveStatus#List status codes and description. dict.solveStatus
Evaluation of Educational program.
Evaluation_Educational_ProgramEvaluation_Educational_Program
A data frame containing data for 22 educational programs.
Programa numeric vector
CCR_EFFa numeric vector
Revenue_Generateda numeric vector
Student_Employeda numeric vector
Employer_Satisfactiona numeric vector
Contact_Hoursa numeric vector
Number_of_FTE_Staffa numeric vector
Facility_Allocationa numeric vector
Expendituresa numeric vector
Bessent A, Bessent W, Cbames A, Cooper WW and Thorgood N (1983) Evaluation of educational program proposals by means of data envelopment analysis. Educational Administrative Quarterly, 19, 82-107.
Bessent A, Bessent W, Cbames A, Cooper WW and Thorgood N (1983) Evaluation of educational program proposals by means of data envelopment analysis. Educational Administrative Quarterly, 19, 82-107.
data(Evaluation_Educational_Program) attach(Evaluation_Educational_Program) x <- data.frame(Contact_Hours, Number_of_FTE_Staff, Facility_Allocation, Expenditures) rownames(x) <- Program colnames(x) <- colnames(Evaluation_Educational_Program)[6:9] y <- data.frame(Revenue_Generated, Student_Employed, Employer_Satisfaction) rownames(y) <- Program colnames(y) <- colnames(Evaluation_Educational_Program)[3:5] detach(Evaluation_Educational_Program) result <- DeaMultiplierModel(x,y,"crs", "input")data(Evaluation_Educational_Program) attach(Evaluation_Educational_Program) x <- data.frame(Contact_Hours, Number_of_FTE_Staff, Facility_Allocation, Expenditures) rownames(x) <- Program colnames(x) <- colnames(Evaluation_Educational_Program)[6:9] y <- data.frame(Revenue_Generated, Student_Employed, Employer_Satisfaction) rownames(y) <- Program colnames(y) <- colnames(Evaluation_Educational_Program)[3:5] detach(Evaluation_Educational_Program) result <- DeaMultiplierModel(x,y,"crs", "input")
Evaluation of Non-Profit organizations efficiency.
Evaluations_Of_NonProfitOrganizationsEvaluations_Of_NonProfitOrganizations
A data frame containing data for 16 Non-Profit organizations.
Hospitala numeric vector
H0a numeric vector
PercentOccupancya numeric vector
RevenuePerDaya numeric vector
A/RTurnovera numeric vector
CostPerDaya numeric vector
LengthOfStaya numeric vector
Greenberg R and Nunamaker T (1987) A generalized multiple criteria model for control and evaluation of nonprofit organizations. Financial Accountability and Management, 3 (4), 331-342.
Greenberg R and Nunamaker T (1987) A generalized multiple criteria model for control and evaluation of nonprofit organizations. Financial Accountability and Management, 3 (4), 331-342.
data(Evaluations_Of_NonProfitOrganizations) attach(Evaluations_Of_NonProfitOrganizations) x <- Evaluations_Of_NonProfitOrganizations detach(Evaluations_Of_NonProfitOrganizations)data(Evaluations_Of_NonProfitOrganizations) attach(Evaluations_Of_NonProfitOrganizations) x <- Evaluations_Of_NonProfitOrganizations detach(Evaluations_Of_NonProfitOrganizations)
Japanese companies data for Operating Efficiency.
data("Japanese_Companies")data("Japanese_Companies")
A data frame with 0 observations on the following 2 variables.
DMUa numeric vector
Companya character vector
Asseta numeric vector
Equitya numeric vector
Employeea numeric vector
Revenuea numeric vector
W.D. Cook, L. Liang, Y. Zha and J.Zhu (2009) A Modified Super-Efficiency DEA Model for Infeasibility, The Journal of the Operational Research Society Vol. 60, No. 2 (Feb., 2009), pp. 276-281.
W.D. Cook, L. Liang, Y. Zha and J.Zhu (2009) A Modified Super-Efficiency DEA Model for Infeasibility, The Journal of the Operational Research Society Vol. 60, No. 2 (Feb., 2009), pp. 276-281.
data(Japanese_Companies) attach(Japanese_Companies)data(Japanese_Companies) attach(Japanese_Companies)
Two-Phase Cross efficiency approach.
Mal_Ben(x = x, y = y, rts ="crs", orientation = "input", phase = "mal", weightRestriction, include = TRUE)Mal_Ben(x = x, y = y, rts ="crs", orientation = "input", phase = "mal", weightRestriction, include = TRUE)
x |
Inputs or resources used by each decision making unit. |
y |
Outputs or resources used by each decision making unit. |
rts |
Returns to scale for the application, or industry studied. Note the default rts is crs. vrs Variable returns to scale. crs Constant returns to scale. Available option: crs, vrs. |
orientation |
Orientation of the DEA model - primary emphasis on input-reduction input or output-augmentation output. Note that unlike the DEA functions, the default is input orientation. Available option: input, output. |
weightRestriction |
Weight restriction for the model. Optional parameter. |
phase |
Second phase of the model. Malevolent or Benevolent. Note the default is mal.Available option: mal, ben. |
include |
In the second phase include evaluating DMU in the calculation. Default is TRUE. Available option: TRUE, FALSE. |
The function returns a number of values per DMU. The standardized efficiency (all inefficiencies are between 0 and 1, for input and output orientation) Efficiency, and the lambda values, lambda, are returned.
$rts |
Returns to scale of the model. |
$Orientation |
Orientation of the model. |
$InputValues |
Input Values (x) passed to the model. |
$OutputValues |
Output Values (y) passed to the model. |
$Phase1_Efficiency |
Efficiency of each DMU in the model from Phase 1. |
$Phase1_Lambda |
Lambdas per DMU in the model from Phase 1. |
$Phase1_vx |
Input weights from the model from Phase 1. |
$Phase1_uy |
Output weights from the model from Phase 1. |
$Phase1_Free_Weights |
Free weights from the model from Phase 1. Applies only to vrs returns-to-scale. |
$Phase1_Model_Status |
Returns the status of the phase two LP model. |
$Phase2_Efficiency |
Efficiency of each DMU in the model from Phase 2. |
$Phase2_Lambda |
Lambdas per DMU in the model from Phase 2. |
$Phase2_vx |
Input weights from the model from Phase 2. |
$Phase2_uy |
Output weights from the model from Phase 2. |
$Phase2_Free_weights |
Free weights from the model from Phase 2. Applies only to vrs returns-to-scale. |
$Phase2_Model_Status |
Returns the status of the phase two LP model. |
$ceva_matrix |
Returns the cross efficiency matrix. Row is the Rating DMU and Column is the Rated DMU. |
$ce_ave |
Returns the cross efficiency score for the DMU. |
$ceva_max |
Returns the maximum cross efficiency score for the DMU. |
$ceva_min |
Returns the minimum cross efficiency score for the DMU. |
ceva_matrix - cross-evaluation matrix. ceva_max - cross-evaluation maximum. ceva_min - cross-evaluation minimum. ce_ave - cross-efficiency scores.
#Example from Kenneth R. Baker: Optimization Modeling with Spreadsheets, Third Edition,p. 176, #John Wiley and Sons, Inc. dmu <- c("A", "B", "C", "D", "E", "F") x <- data.frame(c(150,400,320,520,350,320),c(0.2,0.7,1.2,2.0,1.2,0.7)) rownames(x) <- dmu colnames(x)[1] <- c("StartHours") colnames(x)[2] <- c("Supplies") y <- data.frame(c(14,14,42,28,19,14),c(3.5,21,10.5,42,25,15)) rownames(y) <- dmu colnames(y)[1] <- c("Reimbursed") colnames(y)[2] <- c("Private") # Calculate the efficiency score result <- Mal_Ben(x, y, rts = "crs", orientation = "input",phase = "mal", include = TRUE) # Examine the cross efficiency score for DMUs print(result$ce_ave)#Example from Kenneth R. Baker: Optimization Modeling with Spreadsheets, Third Edition,p. 176, #John Wiley and Sons, Inc. dmu <- c("A", "B", "C", "D", "E", "F") x <- data.frame(c(150,400,320,520,350,320),c(0.2,0.7,1.2,2.0,1.2,0.7)) rownames(x) <- dmu colnames(x)[1] <- c("StartHours") colnames(x)[2] <- c("Supplies") y <- data.frame(c(14,14,42,28,19,14),c(3.5,21,10.5,42,25,15)) rownames(y) <- dmu colnames(y)[1] <- c("Reimbursed") colnames(y)[2] <- c("Private") # Calculate the efficiency score result <- Mal_Ben(x, y, rts = "crs", orientation = "input",phase = "mal", include = TRUE) # Examine the cross efficiency score for DMUs print(result$ce_ave)
Relative Efficiency Metropolitan and London rates departments.
Metropolitan_And_London_Rates_DepartmentsMetropolitan_And_London_Rates_Departments
A data frame containing data for 62 rates department authority.
Authoritya character vector
TotalCosta numeric vector
Non-cnla numeric vector
Ratea numeric vector
Summonsa numeric vector
NPVa numeric vector
Dyson RG and Thanassoulis E (1988) Reducing weight flexibility in Data Envelopment Analysis, Journal of the Operational Research Society, 39 (6), 563-576.
Dyson RG and Thanassoulis E (1988) Reducing weight flexibility in Data Envelopment Analysis, Journal of the Operational Research Society, 39 (6), 563-576.
data(Metropolitan_And_London_Rates_Departments) attach(Metropolitan_And_London_Rates_Departments) x <- data.frame(TotalCost) rownames(x) <- Authority colnames(x) <- colnames(Metropolitan_And_London_Rates_Departments)[2] y <- data.frame(`Non-cnl`, Rate, Summons, NPV) rownames(y) <- Authority colnames(y) <- colnames(Metropolitan_And_London_Rates_Departments)[3:6] detach(Metropolitan_And_London_Rates_Departments) result <- DeaMultiplierModel(x,y,"crs", "input")data(Metropolitan_And_London_Rates_Departments) attach(Metropolitan_And_London_Rates_Departments) x <- data.frame(TotalCost) rownames(x) <- Authority colnames(x) <- colnames(Metropolitan_And_London_Rates_Departments)[2] y <- data.frame(`Non-cnl`, Rate, Summons, NPV) rownames(y) <- Authority colnames(y) <- colnames(Metropolitan_And_London_Rates_Departments)[3:6] detach(Metropolitan_And_London_Rates_Departments) result <- DeaMultiplierModel(x,y,"crs", "input")
MPI model to calculate MPI, Technical change, Efficiency change and Scale efficiency change.
MPI(Dataset = Dataset, DMU_colName = DMU_colName, IP_colNames = IP_colNames, OP_ColNames = OP_ColNames, Period_ColName = Period_ColName, Periods = Periods, rts = "crs", orientation = "input", scale = FALSE)MPI(Dataset = Dataset, DMU_colName = DMU_colName, IP_colNames = IP_colNames, OP_ColNames = OP_ColNames, Period_ColName = Period_ColName, Periods = Periods, rts = "crs", orientation = "input", scale = FALSE)
Dataset |
The data required for the model. |
DMU_colName |
Column name for the DMUs in the dataset. |
IP_colNames |
Column name(s) for all input data in the dataset. |
OP_ColNames |
Column name(s) for all output data in the dataset. |
Period_ColName |
Column name for the period number in the dataset. |
Periods |
Unique periods numbers in the dataset in ascending order. |
rts |
Returns to scale for the application, or industry studied. Note the default rts is crs. vrs Variable returns to scale. crs Constant returns to scale. |
orientation |
Orientation of the DEA model - primary emphasis on input-reduction input or output-augmentation output. Note the default is input orientation. |
scale |
Note default value is FALSE. |
DMU |
DMUs |
et1t1.crs |
The efficiencies for period 1 with reference technology from period 1 for crs returns to scale. Note: available if returns to scale is crs or scale is TRUE. |
et2t2.crs |
The efficiencies for period 2 with reference technology from period 2 for crs returns to scale. Note: available if returns to scale is crs or scale is TRUE. |
et1t2.crs |
The efficiencies for period 2 with reference technology from period 1 for crs returns to scale. Note: available if returns to scale is crs or scale is TRUE. |
et2t1.crs |
The efficiencies for period 1 with reference technology from period 2 for crs returns to scale. Note: available if returns to scale is crs or scale is TRUE. |
et1t1.vrs |
The efficiencies for period 1 with reference technology from period 1 for vrs returns to scale. Note: available if returns to scale is vrs. |
et2t2.vrs |
The efficiencies for period 2 with reference technology from period 2 for vrs returns to scale. Note: available if returns to scale is vrs. |
et1t2.vrs |
The efficiencies for period 2 with reference technology from period 1 for vrs returns to scale. Note: available if returns to scale is vrs. |
et2t1.vrs |
The efficiencies for period 1 with reference technology from period 2 for vrs returns to scale. Note: available if returns to scale is vrs |
sec1 |
First componenet of the scale efficiency change. (et1t2.crs/et1t2.vrs)/(et1t1.crs/et1t1.vrs) |
sec2 |
Second componenet of the scale efficiency change.(et2t2.crs/et2t2.vrs)/(et2t1.crs/et2t1.vrs) |
sec |
Scale efficiency change. (sec1 * sec2) ^ 0.5 |
tc1 |
First component of technical change. For crs, (et1t2.crs/et2t2.crs) and (et1t2.vrs/et2t2.vrs) for vrs. |
tc2 |
Second component of technical change. For crs, (et1t1.crs/et2t1.crs) and (et1t1.vrs/et2t1.vrs) for vrs. |
tc |
Technical change. (tc1 * tc2) ^ 0.5 |
tec or ptec |
Efficiency change. Note: tec for crs and ptec for vrs returns to scale. |
m.crs or m.vrs |
Malmquist Productivity index for the DMUs and periods. |
Year |
Time period underconsideration for MPI. |
Rolf, Fare; Grosskopf, Shawna; Norris, Mary and Zhang, Zhongyang (1994) Productivity Growth, Technical Progress, and Efficiency Change in Industrialized Countries, The American Economic Review Vol. 84, No. 1, pp. 66-83.
da_f <- data.frame(x= c(11, 29, 31, 61, 13, 27, 17, 61), y=c(6, 8, 11, 16, 7, 9, 10, 16), d= c(1,2,3,4, 1,2,3,4), p=c(1,1,1,1,2,2,2,2)) mpi_r <- MPI(Dataset = da_f, DMU_colName = "d", IP_colNames = "x", OP_ColNames = "y", Period_ColName = "p", Periods = c(1,2),rts = "vrs", orientation = "input", scale = TRUE) # Examine the MPI for DMUs mpi_r$m.vrsda_f <- data.frame(x= c(11, 29, 31, 61, 13, 27, 17, 61), y=c(6, 8, 11, 16, 7, 9, 10, 16), d= c(1,2,3,4, 1,2,3,4), p=c(1,1,1,1,2,2,2,2)) mpi_r <- MPI(Dataset = da_f, DMU_colName = "d", IP_colNames = "x", OP_ColNames = "y", Period_ColName = "p", Periods = c(1,2),rts = "vrs", orientation = "input", scale = TRUE) # Examine the MPI for DMUs mpi_r$m.vrs
Provides the orientation option values.
# List the orientation option used as arguments. options.orientation.l# List the orientation option used as arguments. options.orientation.l
Provides the second phase options available for Mal_Ben function.
# List the phase option used as arguments. options.phase.l# List the phase option used as arguments. options.phase.l
Provides the rts (returns to scale) option values.
# List the returns to scale option used as arguments. options.rts.l# List the returns to scale option used as arguments. options.rts.l
SDEA model to calculate the efficieny for each DMUs.
SDEA(x=x, y=y, orientation = "input", rts = "crs", Cook = FALSE)SDEA(x=x, y=y, orientation = "input", rts = "crs", Cook = FALSE)
x |
Inputs or resources used by each decision making unit. |
y |
Outputs or resources used by each decision making unit. |
orientation |
Orientation of the DEA model - primary emphasis on input-reduction input or output-augmentation output. Note the default is input orientation. |
rts |
Returns to scale for the application, or industry studied. Note the default rts is crs. vrs Variable returns to scale. crs Constant returns to scale. |
Cook |
Used with variable returns to scale to address infeasibility in efficiency. Note the default is FALSE. Use TRUE when using vrs rts. |
Input |
Input Values (x) passed to the model. |
Output |
Output Values (y) passed to the model. |
Orientation |
Orientation of the model. |
RTS |
Returns to scale of the model. |
Efficiency |
Efficiency of each DMU in the model. |
Theta |
Used to calculate efficiency if the model is infeasiable. Note: Available only when Cook is set to TRUE. |
Beta |
Used to calculate efficiency if the model is infeasiable.Note: Available only when Cook is set to TRUE. |
Lambda |
Lambdas per DMU in the model. |
StatusData |
Returns the status of the LP model. |
W.D. Cook, L. Liang, Y. Zha and J.Zhu (2009) A Modified Super-Efficiency DEA Model for Infeasibility, The Journal of the Operational Research Society Vol. 60, No. 2 (Feb., 2009), pp. 276-281.
x <-data.frame(matrix(c(12, 26, 16, 60 ),ncol=1)) rownames(x) <- c('a','b','c','d') y <- data.frame(matrix(c(6, 8, 9, 15 ),ncol=1)) rownames(y) <- c('a','b','c','d') result <- SDEA(x=x, y=y, orientation = "input", rts = "crs", Cook = FALSE) # Examine the efficiency score for DMUs print(result$Efficiency)x <-data.frame(matrix(c(12, 26, 16, 60 ),ncol=1)) rownames(x) <- c('a','b','c','d') y <- data.frame(matrix(c(6, 8, 9, 15 ),ncol=1)) rownames(y) <- c('a','b','c','d') result <- SDEA(x=x, y=y, orientation = "input", rts = "crs", Cook = FALSE) # Examine the efficiency score for DMUs print(result$Efficiency)